==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/RawIptablesFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RawIptablesFluent<A extends RawIptablesFluent<A>> extends Fluent<A> {


    public String getDirection();
    public A withDirection(String direction);
    public Boolean hasDirection();
    public A withNewDirection(StringBuilder arg1);
    public A withNewDirection(int[] arg1,int arg2,int arg3);
    public A withNewDirection(char[] arg1);
    public A withNewDirection(StringBuffer arg1);
    public A withNewDirection(byte[] arg1,int arg2);
    public A withNewDirection(byte[] arg1);
    public A withNewDirection(char[] arg1,int arg2,int arg3);
    public A withNewDirection(byte[] arg1,int arg2,int arg3);
    public A withNewDirection(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDirection(String arg1);
    public A addToIpsets(int index,String item);
    public A setToIpsets(int index,String item);
    public A addToIpsets(String... items);
    public A addAllToIpsets(Collection<String> items);
    public A removeFromIpsets(String... items);
    public A removeAllFromIpsets(Collection<String> items);
    public List<String> getIpsets();
    public String getIpset(int index);
    public String getFirstIpset();
    public String getLastIpset();
    public String getMatchingIpset(Predicate<String> predicate);
    public Boolean hasMatchingIpset(Predicate<String> predicate);
    public A withIpsets(List<String> ipsets);
    public A withIpsets(String... ipsets);
    public Boolean hasIpsets();
    public A addNewIpset(StringBuilder arg1);
    public A addNewIpset(int[] arg1,int arg2,int arg3);
    public A addNewIpset(char[] arg1);
    public A addNewIpset(StringBuffer arg1);
    public A addNewIpset(byte[] arg1,int arg2);
    public A addNewIpset(byte[] arg1);
    public A addNewIpset(char[] arg1,int arg2,int arg3);
    public A addNewIpset(byte[] arg1,int arg2,int arg3);
    public A addNewIpset(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewIpset(String arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public String getSource();
    public A withSource(String source);
    public Boolean hasSource();
    public A withNewSource(StringBuilder arg1);
    public A withNewSource(int[] arg1,int arg2,int arg3);
    public A withNewSource(char[] arg1);
    public A withNewSource(StringBuffer arg1);
    public A withNewSource(byte[] arg1,int arg2);
    public A withNewSource(byte[] arg1);
    public A withNewSource(char[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSource(String arg1);
}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/RawIptablesFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RawIptablesFluent<A extends RawIptablesFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getDirection();
    public A withDirection(String direction);
    public Boolean hasDirection();
    public A withNewDirection(StringBuilder arg1);
    public A withNewDirection(int[] arg1,int arg2,int arg3);
    public A withNewDirection(char[] arg1);
    public A withNewDirection(StringBuffer arg1);
    public A withNewDirection(byte[] arg1,int arg2);
    public A withNewDirection(byte[] arg1);
    public A withNewDirection(char[] arg1,int arg2,int arg3);
    public A withNewDirection(byte[] arg1,int arg2,int arg3);
    public A withNewDirection(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDirection(String arg1);
    public A addToIpsets(int index,String item);
    public A setToIpsets(int index,String item);
    public A addToIpsets(String... items);
    public A addAllToIpsets(Collection<String> items);
    public A removeFromIpsets(String... items);
    public A removeAllFromIpsets(Collection<String> items);
    public List<String> getIpsets();
    public String getIpset(int index);
    public String getFirstIpset();
    public String getLastIpset();
    public String getMatchingIpset(Predicate<String> predicate);
    public Boolean hasMatchingIpset(Predicate<String> predicate);
    public A withIpsets(List<String> ipsets);
    public A withIpsets(String... ipsets);
    public Boolean hasIpsets();
    public A addNewIpset(StringBuilder arg1);
    public A addNewIpset(int[] arg1,int arg2,int arg3);
    public A addNewIpset(char[] arg1);
    public A addNewIpset(StringBuffer arg1);
    public A addNewIpset(byte[] arg1,int arg2);
    public A addNewIpset(byte[] arg1);
    public A addNewIpset(char[] arg1,int arg2,int arg3);
    public A addNewIpset(byte[] arg1,int arg2,int arg3);
    public A addNewIpset(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewIpset(String arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public String getSource();
    public A withSource(String source);
    public Boolean hasSource();
    public A withNewSource(StringBuilder arg1);
    public A withNewSource(int[] arg1,int arg2,int arg3);
    public A withNewSource(char[] arg1);
    public A withNewSource(StringBuffer arg1);
    public A withNewSource(byte[] arg1,int arg2);
    public A withNewSource(byte[] arg1);
    public A withNewSource(char[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSource(String arg1);
}
